==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlggroups.h <==
/***************************************************************************
                          dlggroups.h  -  manages a list of groups
                             -------------------
    begin                : St dec 5 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGGROUPS_H
#define DLGGROUPS_H

#include <qwidget.h>
#include <kdialogbase.h>

class cGroupList;
class KListView;
class QListViewItem;
class QPoint;

/**
This dialogs shows a list of groups and can add/modify/delete/activate them.
  *@author Tomas Mecir
  */

class dlgGroups : public KDialogBase {
   Q_OBJECT
public: 
  dlgGroups (cGroupList *groupList, const QString &caption,
        QWidget *parent=0, const char *name=0);
  ~dlgGroups ();
  /** use another group list */
  void switchGroupList (cGroupList *newlist);
  
protected slots:
  void itemClicked (QListViewItem *item);
  void addItem ();
  void renameItem ();
  void deleteItem ();
  void mouseClick (int, QListViewItem *, const QPoint &, int);

  void listDestroyed ();
protected:
  friend class cGroupList;

  void updateView ();

  cGroupList *glist;

  KListView *view;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlggroups.h <==
/***************************************************************************
                          dlggroups.h  -  manages a list of groups
                             -------------------
    begin                : St dec 5 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGGROUPS_H
#define DLGGROUPS_H

#include <qwidget.h>
#include <kdialogbase.h>

class cGroupList;
class KListView;
class QListViewItem;
class QPoint;

/**
This dialogs shows a list of groups and can add/modify/delete/activate them.
  *@author Tomas Mecir
  */

class dlgGroups : public KDialogBase {
   Q_OBJECT
public: 
  dlgGroups (cGroupList *groupList, const QString &caption,
        QWidget *parent=0, const char *name=0);
  ~dlgGroups ();
  /** use another group list */
  void switchGroupList (cGroupList *newlist);
  
  void updateView ();
protected slots:
  void itemClicked (QListViewItem *item);
  void addItem ();
  void renameItem ();
  void deleteItem ();
  void mouseClick (int, QListViewItem *, const QPoint &, int);

  void listDestroyed ();
protected:

  cGroupList *glist;

  KListView *view;
};

#endif
